@@ -29,6 +29,7 @@
 
 import json
 import os.path
+import warnings
 from urllib.request import build_opener, install_opener, ProxyHandler
 
 from qgis.PyQt.QtCore import Qt
@@ -43,7 +44,11 @@ from qgis.core import (QgsApplication, QgsCoordinateReferenceSystem,
 from qgis.gui import QgsRubberBand
 from qgis.utils import OverrideCursor
 
-from owslib.csw import CatalogueServiceWeb # spellok
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=ResourceWarning)
+    warnings.filterwarnings("ignore", category=ImportWarning)
+    from owslib.csw import CatalogueServiceWeb # spellok
+
 from owslib.fes import BBox, PropertyIsLike
 from owslib.ows import ExceptionReport
 
@@ -79,8 +84,10 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
         self.catalog_password = None
         self.context = StaticContext()
 
-        version = self.context.metadata.get('general', 'version')
-        self.setWindowTitle(self.tr('MetaSearch {0}').format(version))
+        self.leKeywords.setShowSearchIcon(True)
+        self.leKeywords.setPlaceholderText(self.tr('Search keywords'))
+
+        self.setWindowTitle(self.tr('MetaSearch'))
 
         self.rubber_band = QgsRubberBand(self.map, True)  # True = a polygon
         self.rubber_band.setColor(QColor(255, 0, 0, 75))
@@ -131,6 +138,7 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
         self.mActionAddWcs.triggered.connect(self.add_to_ows)
         self.mActionAddAms.triggered.connect(self.add_to_ows)
         self.mActionAddAfs.triggered.connect(self.add_to_ows)
+        self.mActionAddGisFile.triggered.connect(self.add_gis_file)
         self.btnShowXml.clicked.connect(self.show_xml)
 
         # settings
@@ -291,7 +299,7 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
         """add new service"""
 
         conn_new = NewConnectionDialog()
-        conn_new.setWindowTitle(self.tr('New Catalog service'))
+        conn_new.setWindowTitle(self.tr('New Catalog Service'))
         if conn_new.exec_() == QDialog.Accepted:  # add to service list
             self.populate_connection_list()
         self.textMetadata.clear()
@@ -304,7 +312,7 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
         url = self.settings.value('/MetaSearch/%s/url' % current_text)
 
         conn_edit = NewConnectionDialog(current_text)
-        conn_edit.setWindowTitle(self.tr('Edit Catalog service'))
+        conn_edit.setWindowTitle(self.tr('Edit Catalog Service'))
         conn_edit.leName.setText(current_text)
         conn_edit.leURL.setText(url)
         conn_edit.leUsername.setText(self.settings.value('/MetaSearch/%s/username' % current_text))
@@ -322,9 +330,9 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
 
         msg = self.tr('Remove service {0}?').format(current_text)
 
-        result = QMessageBox.information(self, self.tr('Confirm delete'), msg,
-                                         QMessageBox.Ok | QMessageBox.Cancel)
-        if result == QMessageBox.Ok:  # remove service from list
+        result = QMessageBox.question(self, self.tr('Delete Service'), msg,
+                                      QMessageBox.Yes | QMessageBox.No, QMessageBox.No)
+        if result == QMessageBox.Yes:  # remove service from list
             self.settings.remove(key)
             index_to_delete = self.cmbConnectionsServices.currentIndex()
             self.cmbConnectionsServices.removeItem(index_to_delete)
@@ -609,12 +617,13 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
             wcs_link_types = list(map(str.upper, link_types.WCS_LINK_TYPES))
             ams_link_types = list(map(str.upper, link_types.AMS_LINK_TYPES))
             afs_link_types = list(map(str.upper, link_types.AFS_LINK_TYPES))
+            gis_file_link_types = list(map(str.upper, link_types.GIS_FILE_LINK_TYPES))
 
             # if the link type exists, and it is one of the acceptable
             # interactive link types, then set
             if all([link_type is not None,
                     link_type in wmswmst_link_types + wfs_link_types +
-                    wcs_link_types + ams_link_types + afs_link_types]):
+                    wcs_link_types + ams_link_types + afs_link_types + gis_file_link_types]):
                 if link_type in wmswmst_link_types:
                     services['wms'] = link['url']
                     self.mActionAddWms.setEnabled(True)
@@ -630,6 +639,10 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
                 if link_type in afs_link_types:
                     services['afs'] = link['url']
                     self.mActionAddAfs.setEnabled(True)
+                if link_type in gis_file_link_types:
+                    services['gis_file'] = link['url']
+                    services['title'] = record.title
+                    self.mActionAddGisFile.setEnabled(True)
                 self.tbAddData.setEnabled(True)
 
             set_item_data(item, 'link', json.dumps(services))
@@ -798,6 +811,22 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
                 ows_provider.cmbConnections_activated(index)
         getattr(ows_provider, connect)()
 
+    def add_gis_file(self):
+        """add GIS file from result"""
+        item = self.treeRecords.currentItem()
+
+        if not item:
+            return
+
+        item_data = json.loads(get_item_data(item, 'link'))
+        gis_file = item_data['gis_file']
+
+        title = item_data['title']
+
+        layer = self.iface.addVectorLayer(gis_file, title, "ogr")
+        if not layer:
+            self.iface.messageBar().pushWarning(None, "Layer failed to load!")
+
     def show_metadata(self):
         """show record metadata"""
 
@@ -864,6 +893,7 @@ class MetaSearchDialog(QDialog, BASE_CLASS):
             self.mActionAddWcs.setEnabled(False)
             self.mActionAddAms.setEnabled(False)
             self.mActionAddAfs.setEnabled(False)
+            self.mActionAddGisFile.setEnabled(False)
 
         if xml:
             self.btnShowXml.setEnabled(False)
