@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 import os
 from collections import OrderedDict
@@ -37,6 +37,7 @@ from qgis.core import (QgsApplication,
                        QgsProcessingException,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterNumber,
+                       QgsProcessingParameterDistance,
                        QgsProcessingParameterField,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterDefinition,
@@ -96,10 +97,9 @@ class Heatmap(QgisAlgorithm):
                                                               self.tr('Point layer'),
                                                               [QgsProcessing.TypeVectorPoint]))
 
-        self.addParameter(QgsProcessingParameterNumber(self.RADIUS,
-                                                       self.tr('Radius (layer units)'),
-                                                       QgsProcessingParameterNumber.Double,
-                                                       100.0, False, 0.0, 9999999999.99))
+        self.addParameter(QgsProcessingParameterDistance(self.RADIUS,
+                                                         self.tr('Radius'),
+                                                         100.0, self.INPUT, False, 0.0))
 
         radius_field_param = QgsProcessingParameterField(self.RADIUS_FIELD,
                                                          self.tr('Radius from field'),
@@ -113,9 +113,9 @@ class Heatmap(QgisAlgorithm):
 
         class ParameterHeatmapPixelSize(QgsProcessingParameterNumber):
 
-            def __init__(self, name='', description='', parent_layer=None, radius_param=None, radius_field_param=None, minValue=None, maxValue=None,
+            def __init__(self, name='', description='', parent_layer=None, radius_param=None, radius_field_param=None, minValue=None,
                          default=None, optional=False):
-                QgsProcessingParameterNumber.__init__(self, name, description, QgsProcessingParameterNumber.Double, default, optional, minValue, maxValue)
+                QgsProcessingParameterNumber.__init__(self, name, description, QgsProcessingParameterNumber.Double, default, optional, minValue)
                 self.parent_layer = parent_layer
                 self.radius_param = radius_param
                 self.radius_field_param = radius_field_param
@@ -130,7 +130,6 @@ class Heatmap(QgisAlgorithm):
                                                      radius_param=self.RADIUS,
                                                      radius_field_param=self.RADIUS_FIELD,
                                                      minValue=0.0,
-                                                     maxValue=9999999999,
                                                      default=0.1)
         pixel_size_param.setMetadata({
             'widget_wrapper': {
@@ -176,6 +175,8 @@ class Heatmap(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
 
         radius = self.parameterAsDouble(parameters, self.RADIUS, context)
         kernel_shape = self.parameterAsEnum(parameters, self.KERNEL, context)
