@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 import os
 import math
@@ -31,12 +31,15 @@ import math
 from qgis.PyQt.QtCore import QVariant
 from qgis.PyQt.QtGui import QIcon
 
-from qgis.core import (QgsFeature,
+from qgis.core import (QgsApplication,
+                       QgsFeature,
                        QgsFeatureSink,
                        QgsWkbTypes,
                        QgsField,
                        QgsProcessing,
+                       QgsProcessingException,
                        QgsProcessingUtils,
+                       QgsProcessingParameterDistance,
                        QgsProcessingParameterNumber,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterFeatureSink)
@@ -55,7 +58,10 @@ class PointsAlongGeometry(QgisAlgorithm):
     END_OFFSET = 'END_OFFSET'
 
     def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'extract_nodes.png'))
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmExtractVertices.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmExtractVertices.svg")
 
     def tags(self):
         return self.tr('create,interpolate,points,lines,regular,distance,by').split(',')
@@ -72,12 +78,12 @@ class PointsAlongGeometry(QgisAlgorithm):
     def initAlgorithm(self, config=None):
         self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT,
                                                               self.tr('Input layer'), [QgsProcessing.TypeVectorPolygon, QgsProcessing.TypeVectorLine]))
-        self.addParameter(QgsProcessingParameterNumber(self.DISTANCE,
-                                                       self.tr('Distance'), type=QgsProcessingParameterNumber.Double, minValue=0.0, defaultValue=1.0))
-        self.addParameter(QgsProcessingParameterNumber(self.START_OFFSET,
-                                                       self.tr('Start offset'), type=QgsProcessingParameterNumber.Double, minValue=0.0, defaultValue=0.0))
-        self.addParameter(QgsProcessingParameterNumber(self.END_OFFSET,
-                                                       self.tr('End offset'), type=QgsProcessingParameterNumber.Double, minValue=0.0, defaultValue=0.0))
+        self.addParameter(QgsProcessingParameterDistance(self.DISTANCE,
+                                                         self.tr('Distance'), parentParameterName=self.INPUT, minValue=0.0, defaultValue=1.0))
+        self.addParameter(QgsProcessingParameterDistance(self.START_OFFSET,
+                                                         self.tr('Start offset'), parentParameterName=self.INPUT, minValue=0.0, defaultValue=0.0))
+        self.addParameter(QgsProcessingParameterDistance(self.END_OFFSET,
+                                                         self.tr('End offset'), parentParameterName=self.INPUT, minValue=0.0, defaultValue=0.0))
 
         self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT, self.tr('Points'), QgsProcessing.TypeVectorPoint))
 
@@ -89,6 +95,9 @@ class PointsAlongGeometry(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         distance = self.parameterAsDouble(parameters, self.DISTANCE, context)
         start_offset = self.parameterAsDouble(parameters, self.START_OFFSET, context)
         end_offset = self.parameterAsDouble(parameters, self.END_OFFSET, context)
@@ -98,7 +107,9 @@ class PointsAlongGeometry(QgisAlgorithm):
         fields.append(QgsField('angle', QVariant.Double))
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               fields, QgsWkbTypes.Point, source.sourceCrs())
+                                               fields, QgsWkbTypes.Point, source.sourceCrs(), QgsFeatureSink.RegeneratePrimaryKey)
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         features = source.getFeatures()
         total = 100.0 / source.featureCount() if source.featureCount() else 0
