@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 import os
 import codecs
@@ -61,7 +61,7 @@ class ReliefColorsWidget(BASE, WIDGET):
         self.btnDown.setIcon(QgsApplication.getThemeIcon('/mActionArrowDown.svg'))
         self.btnLoad.setIcon(QgsApplication.getThemeIcon('/mActionFileOpen.svg'))
         self.btnSave.setIcon(QgsApplication.getThemeIcon('/mActionFileSave.svg'))
-        self.btnAuto.setIcon(QgsApplication.getThemeIcon('/mActionDraw.svg'))
+        self.btnAuto.setIcon(QgsApplication.getThemeIcon('/mActionReload.svg'))
 
         self.layer = None
 
@@ -258,7 +258,7 @@ class ReliefColorsWidgetWrapper(WidgetWrapper):
                 break
 
     def parentValueChanged(self, wrapper):
-        self.setLayer(wrapper.value())
+        self.setLayer(wrapper.parameterValue())
 
     def setLayer(self, layer):
         if isinstance(layer, QgsMapLayer):
