@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
 import os
 import json
@@ -52,6 +52,8 @@ class HelpEditionDialog(BASE, WIDGET):
     ALG_CREATOR = 'ALG_CREATOR'
     ALG_HELP_CREATOR = 'ALG_HELP_CREATOR'
     ALG_VERSION = 'ALG_VERSION'
+    SHORT_DESCRIPTION = 'SHORT_DESCRIPTION'
+    HELP_URL = 'HELP_URL'
 
     def __init__(self, alg):
         super(HelpEditionDialog, self).__init__(None)
@@ -103,6 +105,8 @@ class HelpEditionDialog(BASE, WIDGET):
     def fillTree(self):
         item = TreeDescriptionItem(self.tr('Algorithm description'), self.ALG_DESC)
         self.tree.addTopLevelItem(item)
+        item = TreeDescriptionItem(self.tr('Short description'), self.SHORT_DESCRIPTION)
+        self.tree.addTopLevelItem(item)
         parametersItem = TreeDescriptionItem(self.tr('Input parameters'), None)
         self.tree.addTopLevelItem(parametersItem)
         for param in self.alg.parameterDefinitions():
@@ -124,6 +128,9 @@ class HelpEditionDialog(BASE, WIDGET):
         item = TreeDescriptionItem(self.tr('Algorithm version'),
                                    self.ALG_VERSION)
         self.tree.addTopLevelItem(item)
+        item = TreeDescriptionItem(self.tr('Documentation help URL'),
+                                   self.HELP_URL)
+        self.tree.addTopLevelItem(item)
 
     def changeItem(self):
         item = self.tree.currentItem()
