@@ -23,11 +23,9 @@ __copyright__ = '(C) 2013, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
 
-import csv
-
-from qgis.core import (QgsWkbTypes,
+from qgis.core import (NULL,
                        QgsFeatureRequest)
 
 
@@ -78,7 +76,7 @@ def values(source, *attributes):
 
             # convert attribute value to number
             try:
-                v = float(feature.attributes()[i])
+                v = float(feature[i])
             except:
                 v = None
 
@@ -90,6 +88,16 @@ def values(source, *attributes):
     return ret
 
 
+def convert_nulls(values, replacement=None):
+    """
+    Converts NULL items in a list of values to a replacement value (usually None)
+    :param values: list of values
+    :param replacement: value to use in place of NULL
+    :return: converted list
+    """
+    return [i if i != NULL else replacement for i in values]
+
+
 def checkMinDistance(point, index, distance, points):
     """Check if distance from given point to all other points is greater
     than given value.
